#

##

###

###

###

    	monetary
    		# mongo
    		# moon
    		# data nodes

    	objectives

    		tethered

    			#
    			#	atexit -> close
    			#
    			monetary = build_monetary ({
    				"tethered": "yes"
    			})
    			sanique ["on"] ()
    			sanique ["off"] ()

    		floating
    			vegan stack monetary on
    			vegan stack monetary off
    			vegan stack monetary status

    		restart on code change
    			https://github.com/gorakhargosh/watchdog